import { defineNuxtModule, createResolver, installModule, addComponent } from '@nuxt/kit';

const module = defineNuxtModule({
  meta: {
    name: "nuxt-tour",
    configKey: "tour",
    compatibility: {
      nuxt: ">=3.0"
    }
  },
  // Default configuration options of the Nuxt module
  defaults: {
    prefix: "V",
    injectSass: true
  },
  async setup(options, nuxt) {
    const resolver = createResolver(import.meta.url);
    const runtimeDir = resolver.resolve("./runtime");
    nuxt.options.build.transpile.push(runtimeDir);
    nuxt.options.build.transpile.push("@popperjs/core");
    nuxt.options.alias["#nuxt-tour"] = runtimeDir;
    const isDevelopment = runtimeDir.endsWith("src/runtime") || runtimeDir.endsWith("src\\runtime");
    const extension = isDevelopment ? "scss" : "css";
    if (options.injectSass) {
      nuxt.options.css.unshift(resolver.resolve(`./runtime/scss/tour.${extension}`));
    }
    await installModule("nuxt-icon-tw", { prefix: options.iconPrefix });
    addComponent({
      filePath: resolver.resolve("./runtime/components/Tour.vue"),
      name: options.prefix ? `${options.prefix}Tour` : "Tour"
    });
  }
});

export { module as default };
